# Verify tarball signature with GPGv2.
%global verify_tarball_signature 1

# So far there are no ELF binaries in this package, so the list
# of files in the debuginfo package will be empty, triggering
# an RPM failure.
%global debug_package %{nil}

Summary:       Convert a physical machine to run on KVM
Group:         System/Kernel and hardware
Name:          virt-p2v
Epoch:         1
Version:       1.42.3
Release:       %mkrel 2
License:       GPLv2+

# virt-p2v works only on x86_64 at the moment.  It requires porting
# to properly detect the hardware on other architectures, and furthermore
# virt-v2v requires porting too.
ExclusiveArch: x86_64

# Source and patches.
URL:           https://libguestfs.org/
Source0:       https://download.libguestfs.org/%{name}/%{name}-%{version}.tar.gz
%if 0%{verify_tarball_signature}
Source1:       https://download.libguestfs.org/%{name}/%{name}-%{version}.tar.gz.sig
%endif

# Keyring used to verify tarball signature.
%if 0%{verify_tarball_signature}
Source2:       libguestfs.keyring
%endif

# Basic build requirements.
BuildRequires: gcc
BuildRequires: perl(Pod::Simple)
BuildRequires: perl(Pod::Man)
BuildRequires: perl(List::MoreUtils)
# (tv) for /usr/bin/pod2text:
BuildRequires: perl
BuildRequires: libxml2-devel
BuildRequires: pcre2-devel
BuildRequires: bash-completion
BuildRequires: xz
BuildRequires: gtk3-devel
BuildRequires: dbus-devel
BuildRequires: m4
%if 0%{verify_tarball_signature}
BuildRequires: gnupg2
%endif

# Test suite requirements.
# (tv) for /usr/bin/qemu-nbd:
BuildRequires: qemu-img

#BuildRequires: nbdkit

Requires:      gawk
Requires:      gzip

# virt-p2v-make-disk runs virt-builder:
Requires:      guestfs-tools

# virt-p2v-make-kickstart runs strip:
Requires:      binutils


%description
Virt-p2v converts (virtualizes) physical machines so they can be run
as virtual machines under KVM.

This package contains the tools needed to make a virt-p2v boot CD or
USB key which is booted on the physical machine to perform the
conversion.  You also need virt-v2v installed somewhere else to
complete the conversion.

To convert virtual machines from other hypervisors, see virt-v2v.


%prep
%if 0%{verify_tarball_signature}
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%endif
%autosetup -p1


%build
%configure \
  --with-extra="fedora=%{fedora},release=%{release}"

%make_build


%check
if ! make check; then
    cat test-suite.log
    exit 0
fi


%install
%make_install

# Delete the development man pages.
rm $RPM_BUILD_ROOT%{_mandir}/man1/p2v-building.1*
rm $RPM_BUILD_ROOT%{_mandir}/man1/p2v-hacking.1*
rm $RPM_BUILD_ROOT%{_mandir}/man1/p2v-release-notes.1*


%files
%doc README
%license COPYING
%{_bindir}/virt-p2v-make-disk
%{_bindir}/virt-p2v-make-kickstart
%{_bindir}/virt-p2v-make-kiwi
%{_datadir}/bash-completion/completions/virt-*
%{_datadir}/virt-p2v
%{_libdir}/virt-p2v
%{_mandir}/man1/virt-p2v-make-disk.1*
%{_mandir}/man1/virt-p2v-make-kickstart.1*
%{_mandir}/man1/virt-p2v-make-kiwi.1*
%{_mandir}/man1/virt-p2v.1*




%changelog
* Sat Jun 28 2025 umeabot <umeabot> 1:1.42.3-2.mga10
+ Revision: 2216292
- Mageia 10 Mass Rebuild

* Tue Nov 08 2022 tv <tv> 1:1.42.3-1.mga9
+ Revision: 1904701
- New upstream release 1.42.3

* Wed Jun 29 2022 tv <tv> 1:1.42.1-1.mga9
+ Revision: 1866607
- New upstream release 1.42.1
- gnulib removed upstream.

* Mon Apr 04 2022 umeabot <umeabot> 1:1.42.0-3.mga9
+ Revision: 1843111
- Mageia 9 Mass Rebuild

* Wed Mar 11 2020 tv <tv> 1:1.42.0-2.mga8
+ Revision: 1555604
- set epoch for upgrade

* Wed Mar 11 2020 tv <tv> 1.42.0-1.mga8
+ Revision: 1555598
- ignore testsuite failures (worked OK locally but failed on BS)
- imported package virt-p2v


* Wed Mar 11 2020 Thierry Vignaud <tv@mageia.org> 1.42.0-1.mga8
- import from FC as p2v was split from libguestfs
